==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/python/Pytest.java <==
package io.github.cdklabs.projen.python;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.901Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Pytest")
public class Pytest extends io.github.cdklabs.projen.Component {

    protected Pytest(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Pytest(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pytest(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.python.PytestOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pytest(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Pytest}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Pytest> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.python.PythonProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.python.PythonProject project;
        private io.github.cdklabs.projen.python.PytestOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.python.PythonProject project) {
            this.project = project;
        }

        /**
         * (experimental) Stop the testing process after the first N failures.
         * <p>
         * @return {@code this}
         * @param maxFailures Stop the testing process after the first N failures. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder maxFailures(final java.lang.Number maxFailures) {
            this.options().maxFailures(maxFailures);
            return this;
        }

        /**
         * (experimental) Directory with tests.
         * <p>
         * Default: 'tests'
         * <p>
         * @return {@code this}
         * @param testdir Directory with tests. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder testdir(final java.lang.String testdir) {
            this.options().testdir(testdir);
            return this;
        }

        /**
         * (experimental) Pytest version.
         * <p>
         * Default: "6.2.1"
         * <p>
         * @return {@code this}
         * @param version Pytest version. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options().version(version);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.python.Pytest}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Pytest build() {
            return new io.github.cdklabs.projen.python.Pytest(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.python.PytestOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.python.PytestOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/python/Pytest.java <==
package io.github.cdklabs.projen.python;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.571Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Pytest")
public class Pytest extends io.github.cdklabs.projen.Component {

    protected Pytest(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Pytest(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pytest(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.python.PytestOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pytest(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getTestdir() {
        return software.amazon.jsii.Kernel.get(this, "testdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Pytest}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Pytest> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.python.PytestOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) Stop the testing process after the first N failures.
         * <p>
         * @return {@code this}
         * @param maxFailures Stop the testing process after the first N failures. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder maxFailures(final java.lang.Number maxFailures) {
            this.options().maxFailures(maxFailures);
            return this;
        }

        /**
         * (experimental) Directory with tests.
         * <p>
         * Default: 'tests'
         * <p>
         * @return {@code this}
         * @param testdir Directory with tests. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder testdir(final java.lang.String testdir) {
            this.options().testdir(testdir);
            return this;
        }

        /**
         * (experimental) Pytest version.
         * <p>
         * Default: "7.4.3"
         * <p>
         * @return {@code this}
         * @param version Pytest version. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options().version(version);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.python.Pytest}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Pytest build() {
            return new io.github.cdklabs.projen.python.Pytest(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.python.PytestOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.python.PytestOptions.Builder();
            }
            return this.options;
        }
    }
}
